<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/1999/xhtml" xmlns:ddb="http://rep.oio.dk/sundcom.dk/medcom.dk/xml/schemas/2007/07/01/" xmlns:pbasis="http://rep.oio.dk/sundcom.dk/medcom.dk/xml/schemas/2006/11/14/">
    <xsl:param name="page" select="2"/>
    <xsl:template match="/*">
        <html>
            <head>
                <title>Genoptræningsplan [
                       <xsl:value-of select="/ddb:DenDynamiskeBlanket/ddb:Form/ddb:Data/ddb:Person/pbasis:PersonCivilRegistrationIdentifier"/>
                ]</title>
                <style type="text/css">
                    <![CDATA[
                    body {
                        font-size: 10pt;
                    }
                    
                    table {
                        width: 100%;
                        padding: 10px 0px 10px 0px;
                    }
                    
                    td {
                        background-color: white;
                        width: 50%;
                        padding: 3px;
                    }
                    
                    table.edit {
                      margin: 0px;
                      padding: 0px;
                    }
                    
                    table.edit tr td{
                    border: 1px solid black;
                    min-height: 1em;
                    width: auto;
                    }
                    
                    td.field {
                        border: 1px solid black;
                        min-height: 1em;
                    }

                    td.container {
                        padding: 0px;
                        margin: 0px;
                        background-color: transparent;
                    }

                     td.heading {
                         background-color: #f1e3fc;
                         border: 1px solid black;
                     }
                     
                     div.background {
                         background-color: #9f95a6;
                         border: 1px solid black;
                         margin: 10px;
                         padding: 10px;
                         width: 60em;
                     }
                     
                     h4 {
                         font-size: 14pt;
                         margin: 10px 2px 0px 10px;
                         padding-left: 2px;
                     }
                     
                     h5 {
                     font-size: 12pt;
                     margin: 0px 2px 0px 10px;
                     padding-left: 2px;
                     }
                     
                     h6 {
                     font-size: 10pt;
                     margin: 0px 2px 0px 2px;
                     padding-left: 2px;
                     }
                     h7 {
                     font-size: 8pt;
                     margin: 0px 2px 0px 2px;
                     padding-left: 2px;
                     }
                     
                     span.generaltext {
                         padding: 5px;
                     }
                ]]></style>
            </head>
            <body>
                <div class="background">
                    <h4>Genoptræningsplan <small>v.<xsl:value-of select="ddb:Form/ddb:VersionCode"/></small></h4>
                    
                    <table>
                        <tr>
                            <td class="heading">Modtager</td>
                            <td class="heading">Patient</td>
                        </tr>
                        <tr>
                            <td class="field">
                                <xsl:apply-templates select="ddb:Form/ddb:Data/ddb:Receiver"/>
                            </td>
                            <td class="field">
                                <xsl:apply-templates select="ddb:Form/ddb:Data/ddb:Person"/>
                            </td>
                        </tr>
                    </table>
                    <table>
                        <tr>
                            <td class="heading">Kopi til egen læge</td>
                            <td class="heading">Afsender</td>
                        </tr>
                        <tr>
                            <td class="field">
                                <xsl:apply-templates select="ddb:Form/ddb:Data/ddb:CCReceiver"/>
                            </td>
                            <td class="field">
                                <xsl:apply-templates select="ddb:Form/ddb:Data/ddb:Sender"/>
                            </td>
                        </tr>
                    </table>
                    <xsl:apply-templates select="ddb:Form/ddb:Data/ddb:UserFields/*"/>
                </div>
            </body>
        </html>

    </xsl:template>

    <xsl:template match="ddb:Receiver">
        <table>
            <xsl:apply-templates select="pbasis:*"/>
        </table>
    </xsl:template>

    <xsl:template match="ddb:Person">
        <table>
            <xsl:apply-templates select="pbasis:*"/>
        </table>
    </xsl:template>

    <xsl:template match="ddb:Sender">
        <table>
            <xsl:apply-templates select="pbasis:*"/>
        </table>
    </xsl:template>

    <xsl:template match="ddb:CCReceiver">
        <table>
            <xsl:apply-templates select="pbasis:*"/>
        </table>
    </xsl:template>

    <xsl:template match="pbasis:EANIdentifier">
        <tr>
            <td>EAN:</td>
            <td width="90%">
                <xsl:value-of select="."/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="pbasis:Indentifier">
        <xsl:if test="string-length(text())">
            <tr>
                <td>
                    <xsl:value-of select="../pbasis:IndentifierCode"/>
                </td>
                <td width="90%">
                    <xsl:value-of select="text()"/>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    
    
    <xsl:template match="pbasis:PersonCivilRegistrationIdentifier">
        <xsl:if test="string-length(text())">
            <tr>
                <td>
                    CPR nummer:
                </td>
                <td width="90%">
                    <xsl:value-of select="concat(substring(text(), 0, 7), '-', substring(text(),7))"/>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    

    <xsl:template match="pbasis:OrganisationName">
        <tr>
            <td/>
            <td width="90%">
                <xsl:if test="text()">
                    <xsl:value-of select="."/>
                </xsl:if>
                <xsl:if test="../pbasis:DepartmentName/text()">, <xsl:value-of select="../pbasis:DepartmentName"/></xsl:if>
                <xsl:if test="../pbasis:UnitName/text()">, <xsl:value-of select="../pbasis:UnitName"/></xsl:if>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="pbasis:StreetName">
        <tr>
            <td>Adresse</td>
            <td width="90%">
                <xsl:value-of select="."/>
                <xsl:if test="../pbasis:SuburbName">, <xsl:value-of select="../pbasis:SuburbName"/></xsl:if>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="pbasis:PostCodeIdentifier">
        <tr>
            <td/>
            <td width="90%"><xsl:value-of select="."/>, <xsl:value-of select="../pbasis:DistrictName"/></td>
        </tr>
    </xsl:template>

    <xsl:template match="pbasis:PersonTitleIdentifier">
        <tr>
            <td/>
            <td width="90%">
                <xsl:value-of select="."/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="../pbasis:PersonGivenName"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="../pbasis:PersonSurnameName"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="ddb:FieldGroup">
        <xsl:if test="@ShortPrompt and string-length(@ShortPrompt)">
            <h4>
                <xsl:value-of select="@ShortPrompt"/>
            </h4>
        </xsl:if>
        <xsl:if test="@SecondPrompt and string-length(@SecondPrompt)">
            <h5>
                <xsl:value-of select="@SecondPrompt"/>
            </h5>
        </xsl:if>
        <xsl:apply-templates select="ddb:FieldX"/>
    </xsl:template>

    <xsl:template match="ddb:FieldX">
        <xsl:if test="@GeneralText and string-length(@GeneralText)">
            <span class="generaltext">
                <xsl:value-of select="@GeneralText"/>
            </span>
        </xsl:if>
        <table>
            <tr>
                <td class="heading" colspan="2">
                    <h6>
                        <xsl:value-of select="@ShortPrompt"/>
                    </h6>
                    <xsl:if test="@SecondPrompt and string-length(@SecondPrompt)">
                        <h7>
                            <xsl:value-of select="@SecondPrompt"/>
                        </h7>
                    </xsl:if>
                </td>
            </tr>
            <xsl:apply-templates select="*"/>
        </table>
    </xsl:template>

    <xsl:template match="ddb:TableEdit">
        <tr>
            <td colspan="2" class="container">
                <table class="edit">
                    <xsl:for-each select="ddb:RowX">
                        <xsl:if test="not(string-length(ddb:*/text()) = 0)">
                        <tr>
                            <xsl:apply-templates select="ddb:ColumnX"/>
                        </tr>
                        </xsl:if>
                    </xsl:for-each>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="ddb:ColumnX[@DataType = 'string']">
        <td>
            <xsl:if test="@ReadOnly = 1">
                <xsl:attribute name="class">heading</xsl:attribute>
            </xsl:if>
            <xsl:value-of select="."/>
        </td>
    </xsl:template>

    <xsl:template match="ddb:ColumnX[@DataType = 'date']">
        <td>
            <xsl:if test="@ReadOnly = 1">
                <xsl:attribute name="class">heading</xsl:attribute>
            </xsl:if>
            <xsl:value-of select="."/>
        </td>
    </xsl:template>

    <xsl:template match="ddb:ColumnX[@DataType = 'checkbox']">
        <td>
            <xsl:if test="@ReadOnly = 1">
                <xsl:attribute name="class">heading</xsl:attribute>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="text() = 1">Ja</xsl:when>
                <xsl:otherwise>Nej</xsl:otherwise>
            </xsl:choose>
        </td>
    </xsl:template>

    <xsl:template match="ddb:ColumnX[@DataType = 'decimal']">
        <td>
            <xsl:if test="@ReadOnly = 1">
                <xsl:attribute name="class">heading</xsl:attribute>
            </xsl:if>
            <xsl:value-of select="."/>
        </td>
    </xsl:template>


    <xsl:template match="ddb:InlineFile">
        <tr>
            <td class="Field">
                <i>Vedhæftelse ikke understøttet</i>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="ddb:CheckBoxes | ddb:RadioButtons">
        <xsl:apply-templates select="ddb:CheckBoxX | ddb:RadioButtonX"/>
    </xsl:template>

    <xsl:template match="ddb:CheckBox | ddb:CheckBoxX | ddb:RadioButtonX">
        <tr>
            <td class="heading">
                <xsl:value-of select="@SecondPrompt"/>
            </td>
            <td class="field">
                <xsl:choose>
                    <xsl:when test="text() = 1">Ja</xsl:when>
                    <xsl:otherwise>Nej</xsl:otherwise>
                </xsl:choose>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="ddb:DateEdit">
        <tr>
            <td class="field" colspan="2">
                <xsl:value-of select="text()"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="ddb:MultilineEdit">
        <tr>
            <td class="field" colspan="2">
                <xsl:apply-templates mode="multiline" select="text() | *"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template mode="multiline" match="ddb:br">
        <br/>
    </xsl:template>

    <xsl:template mode="multiline" match="ddb:b">
        <b>
            <xsl:apply-templates select="text() | *"/>
        </b>
    </xsl:template>

    <xsl:template mode="multiline" match="text()">
        <xsl:value-of select="."/>
    </xsl:template>

    <xsl:template match="*"/>

</xsl:stylesheet>
